@@ -256,12 +256,16 @@ def show_archives():
 
 
 @click.command()
+@click.option("--resume-from", default=0, help="Resume from this member ID")
 @transaction.atomic()
-def process_members():
+def process_members(resume_from: int):
     """Process each member"""
     import exporter
 
-    exporter.generate_report()
+    if resume_from > 0:
+        logging.info("Resuming from member ID {}".format(resume_from))
+
+    exporter.generate_report(resume_from)
 
 
 @click.command()
