@@ -356,7 +356,7 @@ def process_sample(
     return {member_id: overall_status}
 
 
-def generate_report():
+def generate_report(resume_from: int):
     SAMPLES_BUCKET = "samples-crossref-research"
     SAMPLES_PATH = "members-works/sample-2023-01-21/works/"
 
@@ -399,6 +399,7 @@ def generate_report():
             CODE_BUCKET,
         )
         for member_id in members
+        if int(member_id) >= resume_from
     )
 
     return members
